@@ -1,2 +1,2 @@
 """Conversations: A python library for analysis of conversations."""
-from ._conversations import Conversation
+from ._conversations import Conversation, load_conversation
